#!/bin/sh
export PATH='/usr/lib/llvm15/bin/:/usr/lib/ccache/bin:/usr/bin'
printf '%s' 'name:                 scientific
version:              0.3.7.0
visibility:           public
id:                   scientific-0.3.7.0-2q9JvA6xK2eIxznb1eD5ba
key:                  scientific-0.3.7.0-2q9JvA6xK2eIxznb1eD5ba
license:              BSD-3-Clause
maintainer:           Bas van Dijk <v.dijk.bas@gmail.com>
author:               Bas van Dijk
homepage:             https://github.com/basvandijk/scientific
synopsis:             Numbers represented using scientific notation
description:
    "Data.Scientific" provides the number type '\''Scientific'\''. Scientific numbers are
    arbitrary precision and space efficient. They are represented using
    <http://en.wikipedia.org/wiki/Scientific_notation scientific notation>.
    The implementation uses a coefficient @c :: '\''Integer'\''@ and a base-10 exponent
    @e :: '\''Int'\''@. A scientific number corresponds to the
    '\''Fractional'\'' number: @'\''fromInteger'\'' c * 10 '\''^^'\'' e@.

    Note that since we'\''re using an '\''Int'\'' to represent the exponent these numbers
    aren'\''t truly arbitrary precision. I intend to change the type of the exponent
    to '\''Integer'\'' in a future release.

    The main application of '\''Scientific'\'' is to be used as the target of parsing
    arbitrary precision numbers coming from an untrusted source. The advantages
    over using '\''Rational'\'' for this are that:

    * A '\''Scientific'\'' is more efficient to construct. Rational numbers need to be
    constructed using '\''%'\'' which has to compute the '\''gcd'\'' of the '\''numerator'\'' and
    '\''denominator'\''.

    * '\''Scientific'\'' is safe against numbers with huge exponents. For example:
    @1e1000000000 :: '\''Rational'\''@ will fill up all space and crash your
    program. Scientific works as expected:

    >>> read "1e1000000000" :: Scientific
    1.0e1000000000

    * Also, the space usage of converting scientific numbers with huge exponents to
    @'\''Integral'\''s@ (like: '\''Int'\'') or @'\''RealFloat'\''s@ (like: '\''Double'\'' or '\''Float'\'')
    will always be bounded by the target type.

category:             Data
abi:                  442c9a2c0d809e10d02d468e4dd12e9a
exposed:              True
exposed-modules:
    Data.ByteString.Builder.Scientific Data.Scientific
    Data.Text.Lazy.Builder.Scientific

hidden-modules:       GHC.Integer.Compat Utils
import-dirs:          /usr/lib/ghc-9.8.2/site-local/scientific-0.3.7.0
library-dirs:         /usr/lib/ghc-9.8.2/site-local/scientific-0.3.7.0
library-dirs-static:  /usr/lib/ghc-9.8.2/site-local/scientific-0.3.7.0
dynamic-library-dirs: /usr/lib/x86_64-linux-ghc-9.8.2
data-dir:             /usr/share/x86_64-linux-ghc-9.8.2/scientific-0.3.7.0
hs-libraries:         HSscientific-0.3.7.0-2q9JvA6xK2eIxznb1eD5ba
depends:
    base-4.19.1.0-inplace binary-0.8.9.1-inplace
    bytestring-0.12.1.0-inplace containers-0.6.8-inplace
    deepseq-1.5.0.0-inplace hashable-1.4.4.0-4FjbwRHK8slL7OrZ7pqlVV
    integer-logarithms-1.0.3.1-1LR6NH03mpo16pETO3cOzz
    primitive-0.9.0.0-3Z6MZnSLD38BpiHT3vTCWH
    template-haskell-2.21.0.0-inplace text-2.1.1-inplace

haddock-interfaces:
    /usr/share/doc/x86_64-linux-ghc-9.8.2/scientific-0.3.7.0/html/scientific.haddock

haddock-html:
    /usr/share/doc/x86_64-linux-ghc-9.8.2/scientific-0.3.7.0/html
' | '/usr/bin/ghc-pkg-9.8.2' 'update' '-' '--global' '--no-user-package-db' "$@"

